/* Keypadtest.pde
 * 
 * Para utilizar este exemplo copie a pasta keypad para dentro da
 * pasta libraries do Arduino Alpha
 *
 * Keypad Library for Arduino
 * Autor:  Mark Stanley, Alexander Brevig
 * Contato: mstanley@technologist.com, alexanderbrevig@gmail.com
 *
 * Modificado por: Pedro Zuchi
 * Contato: pedrozuchi@hotmail.com
 *
 * Demonstrar o uso mais simples da biblioteca teclado
 *
 * O primeiro passo é conectar o teclado com a placa Arduino
 * utilizando os números dos pinos listadas na matriz abaixo
 * RowPins [] e colPins []. Se você quiser usar pinos diferentes,
 * altere os números abaixo para corresponder à sua configuração.
 *
 * Mais informações em: http://arduino.cc/playground/Code/Keypad
 *
*/

#include <Keypad.h>

const byte ROWS = 4; // Quatro linhas
const byte COLS = 4; // Quatro colunas

// Define o mapa de teclas
 char keys [ROWS] [COLS] = {
   {'1', '2', '3', '4'},
   {'5', '6', '7', '8'},
   {'9', '0', 'C', 'E'},
   {'<', '+', '-', '>'}
 };
 
// Conecta teclado LIN1, LIN2, LIN3 e LIN4 a esses pinos do Arduino.
byte rowPins [ROWS] = {8, 7, 6, 5};
// Conecta teclado COL1, COL2, COL3 e COL4 a esses pinos do Arduino.
byte colPins [COLS] = {12, 11, 10, 9}; 

// Cria o teclado
Keypad kpd = Keypad (makeKeymap (keys), rowPins, colPins, ROWS, COLS);

#define ledPin 13

 void setup ()
 {
   digitalWrite (ledPin, HIGH);
   Serial.begin (9600);
 }

 void loop ()
 {
   char key = kpd.getKey ();
   if (key) // Verificar se há uma chave válida.
   {
     switch (key)
     {
       case '<':
         digitalWrite (ledPin, LOW);
         break;
       case '>':
         digitalWrite (ledPin, HIGH);
         break;
       default:
         Serial.println (key);
     }
   }
 }


